API Reference
=============

Directory layout
----------------

.. automodule:: dirlay.dir
    :members:
    :special-members: __eq__, __iter__

Formatting
----------

.. autofunction:: dirlay.format_rich.to_tree
